You are viewing a plain text version of this content. The canonical link for it is here.
Posted to commits@maven.apache.org by mi...@apache.org on 2023/01/20 22:57:02 UTC

[maven-doxia] branch DOXIA-685 updated (ee2d76f6 -> 323404ca)

This is an automated email from the ASF dual-hosted git repository.

michaelo pushed a change to branch DOXIA-685
in repository https://gitbox.apache.org/repos/asf/maven-doxia.git


    omit ee2d76f6 [DOXIA-685] Replace SinkEventAttributes#BOXED and clearly separate between regular verbatim and verbatim source (code)
     add bb53b6d4 Remove incorrect Javadoc statements
     add 4bf7febd [DOXIA-688] Remove empty alt attribute value on images which causes the browser not to render replacement icon
     add 7509feb0 [DOXIA-689] Restore incorrectly removed (HTML5) attributes
     new 323404ca [DOXIA-685] Replace SinkEventAttributes#BOXED and clearly separate between regular verbatim and verbatim source (code)

This update added new revisions after undoing existing revisions.
That is to say, some revisions that were in the old version of the
branch are not in the new version.  This situation occurs
when a user --force pushes a change and generates a repository
containing something like this:

 * -- * -- B -- O -- O -- O   (ee2d76f6)
            \
             N -- N -- N   refs/heads/DOXIA-685 (323404ca)

You should already have received notification emails for all of the O
revisions, and so the following emails describe only the N revisions
from the common base, B.

Any revisions marked "omit" are not gone; other references still
refer to them.  Any revisions marked "discard" are gone forever.

The 1 revisions listed above as "new" are entirely new to this
repository and will be described in separate emails.  The revisions
listed as "add" were already present in the repository and have only
been added to this reference.


Summary of changes:
 .../main/java/org/apache/maven/doxia/sink/impl/SinkUtils.java  |  1 +
 .../java/org/apache/maven/doxia/sink/impl/Xhtml5BaseSink.java  | 10 +++-------
 .../org/apache/maven/doxia/sink/impl/Xhtml5BaseSinkTest.java   |  4 ++--
 .../main/java/org/apache/maven/doxia/module/fml/FmlParser.java |  4 +++-
 .../main/java/org/apache/maven/doxia/module/xdoc/XdocSink.java |  5 +----
 .../java/org/apache/maven/doxia/module/xdoc/XdocSinkTest.java  |  2 +-
 .../org/apache/maven/doxia/module/xhtml5/Xhtml5SinkTest.java   |  2 +-
 .../doxia-module-xhtml5/src/test/resources/index.xml.vm        | 10 +++++-----
 .../src/main/resources/maven-site/xdoc/index.xml.vm            |  4 ++--
 9 files changed, 19 insertions(+), 23 deletions(-)


[maven-doxia] 01/01: [DOXIA-685] Replace SinkEventAttributes#BOXED and clearly separate between regular verbatim and verbatim source (code)

Posted by mi...@apache.org.
This is an automated email from the ASF dual-hosted git repository.

michaelo pushed a commit to branch DOXIA-685
in repository https://gitbox.apache.org/repos/asf/maven-doxia.git

commit 323404ca7699b6c8771ec454633d9935fbd01b90
Author: Michael Osipov <mi...@apache.org>
AuthorDate: Mon Jan 9 12:30:28 2023 +0100

    [DOXIA-685] Replace SinkEventAttributes#BOXED and clearly separate between regular verbatim and verbatim source (code)
    
    This closes #135
---
 .../org/apache/maven/doxia/macro/EchoMacro.java    |   3 +-
 .../maven/doxia/macro/snippet/SnippetMacro.java    |  12 +-
 .../maven/doxia/parser/Xhtml5BaseParser.java       |  14 +--
 .../doxia/sink/impl/SinkEventAttributeSet.java     |   9 ++
 .../maven/doxia/sink/impl/Xhtml5BaseSink.java      |  13 +-
 .../maven/doxia/sink/impl/AbstractSinkTest.java    | 138 ++++++++++-----------
 .../doxia/sink/impl/SinkEventAttributeSetTest.java |  18 +--
 .../maven/doxia/sink/impl/SinkTestDocument.java    |   8 +-
 .../maven/doxia/sink/impl/SinkUtilsTest.java       |   6 +-
 .../org/apache/maven/doxia/sink/impl/TextSink.java |   6 +-
 .../maven/doxia/sink/impl/Xhtml5BaseSinkTest.java  |  19 +--
 .../apache/maven/doxia/module/apt/AptMarkup.java   |  16 +--
 .../apache/maven/doxia/module/apt/AptParser.java   |   8 +-
 .../org/apache/maven/doxia/module/apt/AptSink.java |  26 ++--
 .../maven/doxia/module/apt/AptParserTest.java      |   8 +-
 .../apache/maven/doxia/module/apt/AptSinkTest.java |   6 +-
 .../maven/doxia/module/fml/FmlContentParser.java   |   2 +-
 .../doxia/module/markdown/MarkdownMarkup.java      |   8 +-
 .../doxia/module/markdown/MarkdownParser.java      |   5 +-
 .../maven/doxia/module/markdown/MarkdownSink.java  |   4 +-
 .../doxia/module/markdown/MarkdownParserTest.java  |   4 +-
 .../doxia/module/markdown/MarkdownSinkTest.java    |   6 +-
 .../apache/maven/doxia/module/xdoc/XdocParser.java |   2 +-
 .../apache/maven/doxia/module/xdoc/XdocSink.java   |  16 +--
 .../maven/doxia/module/xdoc/XdocSinkTest.java      |   6 +-
 .../maven/doxia/module/xhtml5/Xhtml5Parser.java    |  18 +--
 .../maven/doxia/module/xhtml5/Xhtml5SinkTest.java  |   4 +-
 .../java/org/apache/maven/doxia/sink/Sink.java     |   2 +-
 .../maven/doxia/sink/SinkEventAttributes.java      |   2 +-
 29 files changed, 203 insertions(+), 186 deletions(-)

diff --git a/doxia-core/src/main/java/org/apache/maven/doxia/macro/EchoMacro.java b/doxia-core/src/main/java/org/apache/maven/doxia/macro/EchoMacro.java
index f276b961..b3411c68 100644
--- a/doxia-core/src/main/java/org/apache/maven/doxia/macro/EchoMacro.java
+++ b/doxia-core/src/main/java/org/apache/maven/doxia/macro/EchoMacro.java
@@ -41,7 +41,6 @@ import javax.inject.Named;
 import javax.inject.Singleton;
 
 import org.apache.maven.doxia.sink.Sink;
-import org.apache.maven.doxia.sink.impl.SinkEventAttributeSet;
 
 /**
  * A simple macro that prints out the key and value of some supplied parameters.
@@ -51,7 +50,7 @@ import org.apache.maven.doxia.sink.impl.SinkEventAttributeSet;
 public class EchoMacro extends AbstractMacro {
     /** {@inheritDoc} */
     public void execute(Sink sink, MacroRequest request) {
-        sink.verbatim(SinkEventAttributeSet.BOXED);
+        sink.verbatim();
 
         sink.text("echo" + EOL);
 
diff --git a/doxia-core/src/main/java/org/apache/maven/doxia/parser/Xhtml5BaseParser.java b/doxia-core/src/main/java/org/apache/maven/doxia/parser/Xhtml5BaseParser.java
index a0b7a105..4d54e1d3 100644
--- a/doxia-core/src/main/java/org/apache/maven/doxia/parser/Xhtml5BaseParser.java
+++ b/doxia-core/src/main/java/org/apache/maven/doxia/parser/Xhtml5BaseParser.java
@@ -821,16 +821,16 @@ public class Xhtml5BaseParser extends AbstractXmlParser implements HtmlMarkup {
     }
 
     private boolean handleDivStart(XmlPullParser parser, SinkEventAttributeSet attribs, Sink sink) {
-        String divclass = parser.getAttributeValue(null, Attribute.CLASS.toString());
+        String divClass = parser.getAttributeValue(null, Attribute.CLASS.toString());
 
-        this.divStack.push(divclass);
+        this.divStack.push(divClass);
 
-        if ("content".equals(divclass)) {
+        if ("content".equals(divClass)) {
             SinkEventAttributeSet atts = new SinkEventAttributeSet(attribs);
             atts.removeAttribute(SinkEventAttributes.CLASS);
             sink.content(atts);
         }
-        if ("source".equals(divclass)) {
+        if ("verbatim".equals(divClass) || "verbatim source".equals(divClass)) {
             return false;
         } else {
             sink.division(attribs);
@@ -840,12 +840,12 @@ public class Xhtml5BaseParser extends AbstractXmlParser implements HtmlMarkup {
     }
 
     private boolean handleDivEnd(Sink sink) {
-        String divclass = divStack.pop();
+        String divClass = divStack.pop();
 
-        if ("content".equals(divclass)) {
+        if ("content".equals(divClass)) {
             sink.content_();
         }
-        if ("source".equals(divclass)) {
+        if ("verbatim".equals(divClass) || "verbatim source".equals(divClass)) {
             return false;
         } else {
             sink.division_();
diff --git a/doxia-core/src/main/java/org/apache/maven/doxia/sink/impl/SinkEventAttributeSet.java b/doxia-core/src/main/java/org/apache/maven/doxia/sink/impl/SinkEventAttributeSet.java
index fda46776..2977cb17 100644
--- a/doxia-core/src/main/java/org/apache/maven/doxia/sink/impl/SinkEventAttributeSet.java
+++ b/doxia-core/src/main/java/org/apache/maven/doxia/sink/impl/SinkEventAttributeSet.java
@@ -70,9 +70,17 @@ public class SinkEventAttributeSet implements SinkEventAttributes, Cloneable {
 
     /**
      * An unmodifiable attribute set containing only a boxed attribute.
+     *
+     * @deprecated use {@link source} for source code
      */
+    @Deprecated
     public static final SinkEventAttributes BOXED;
 
+    /**
+     * An unmodifiable attribute set containing only a source attribute.
+     */
+    public static final SinkEventAttributes SOURCE;
+
     /**
      * An unmodifiable attribute set containing only a bold attribute.
      */
@@ -113,6 +121,7 @@ public class SinkEventAttributeSet implements SinkEventAttributes, Cloneable {
         OVERLINE = new SinkEventAttributeSet(DECORATION, "overline").unmodifiable();
         LINETHROUGH = new SinkEventAttributeSet(DECORATION, "line-through").unmodifiable();
         BOXED = new SinkEventAttributeSet(DECORATION, "boxed").unmodifiable();
+        SOURCE = new SinkEventAttributeSet(DECORATION, "source").unmodifiable();
 
         BOLD = new SinkEventAttributeSet(STYLE, "bold").unmodifiable();
         ITALIC = new SinkEventAttributeSet(STYLE, "italic").unmodifiable();
diff --git a/doxia-core/src/test/java/org/apache/maven/doxia/sink/impl/SinkEventAttributeSetTest.java b/doxia-core/src/test/java/org/apache/maven/doxia/sink/impl/SinkEventAttributeSetTest.java
index ef26c5ec..a975ead4 100644
--- a/doxia-core/src/test/java/org/apache/maven/doxia/sink/impl/SinkEventAttributeSetTest.java
+++ b/doxia-core/src/test/java/org/apache/maven/doxia/sink/impl/SinkEventAttributeSetTest.java
@@ -98,7 +98,7 @@ public class SinkEventAttributeSetTest {
 
         sinkEventAttributeSet.addAttributes(SinkEventAttributeSet.BOLD);
         assertEquals(1, sinkEventAttributeSet.getAttributeCount());
-        sinkEventAttributeSet.removeAttributes(SinkEventAttributeSet.BOXED);
+        sinkEventAttributeSet.removeAttributes(SinkEventAttributeSet.SOURCE);
         assertEquals(1, sinkEventAttributeSet.getAttributeCount());
         sinkEventAttributeSet.removeAttributes(SinkEventAttributeSet.BOLD);
         assertEquals(0, sinkEventAttributeSet.getAttributeCount());
@@ -110,7 +110,7 @@ public class SinkEventAttributeSetTest {
     @Test
     public void testIsDefined() {
         assertFalse(sinkEventAttributeSet.isDefined(SinkEventAttributes.DECORATION));
-        sinkEventAttributeSet.addAttributes(SinkEventAttributeSet.BOXED);
+        sinkEventAttributeSet.addAttributes(SinkEventAttributeSet.SOURCE);
         assertTrue(sinkEventAttributeSet.isDefined(SinkEventAttributes.DECORATION));
     }
 
@@ -122,7 +122,7 @@ public class SinkEventAttributeSetTest {
         SinkEventAttributes instance = new SinkEventAttributeSet(SinkEventAttributeSet.BOLD);
         sinkEventAttributeSet.addAttributes(SinkEventAttributeSet.BOLD);
         assertTrue(instance.isEqual(sinkEventAttributeSet));
-        instance.addAttributes(SinkEventAttributeSet.BOXED);
+        instance.addAttributes(SinkEventAttributeSet.SOURCE);
         assertFalse(instance.isEqual(sinkEventAttributeSet));
     }
 
@@ -139,7 +139,7 @@ public class SinkEventAttributeSetTest {
         SinkEventAttributes instance = new SinkEventAttributeSet(SinkEventAttributeSet.BOLD);
         sinkEventAttributeSet.addAttributes(SinkEventAttributeSet.BOLD);
         assertTrue(instance.equals(sinkEventAttributeSet));
-        instance.addAttributes(SinkEventAttributeSet.BOXED);
+        instance.addAttributes(SinkEventAttributeSet.SOURCE);
         assertFalse(instance.equals(sinkEventAttributeSet));
     }
 
@@ -191,7 +191,7 @@ public class SinkEventAttributeSetTest {
     public void testContainsAttributes() {
         sinkEventAttributeSet.addAttributes(SinkEventAttributeSet.JUSTIFY);
         assertTrue(sinkEventAttributeSet.containsAttributes(SinkEventAttributeSet.JUSTIFY));
-        assertFalse(sinkEventAttributeSet.containsAttributes(SinkEventAttributeSet.BOXED));
+        assertFalse(sinkEventAttributeSet.containsAttributes(SinkEventAttributeSet.SOURCE));
     }
 
     /**
@@ -256,7 +256,7 @@ public class SinkEventAttributeSetTest {
 
         result = sinkEventAttributeSet.clone();
         assertEquals(sinkEventAttributeSet, result);
-        sinkEventAttributeSet.setResolveParent(SinkEventAttributeSet.BOXED);
+        sinkEventAttributeSet.setResolveParent(SinkEventAttributeSet.SOURCE);
         // assertFalse( sinkEventAttributeSet.equals( result ) );
     }
 
@@ -284,12 +284,12 @@ public class SinkEventAttributeSetTest {
         String expected = "";
         assertEquals(expected, sinkEventAttributeSet.toString());
 
-        sinkEventAttributeSet.addAttributes(SinkEventAttributeSet.BOXED);
-        expected = " decoration=boxed";
+        sinkEventAttributeSet.addAttributes(SinkEventAttributeSet.SOURCE);
+        expected = " decoration=source";
         assertEquals(expected, sinkEventAttributeSet.toString());
 
         sinkEventAttributeSet.addAttributes(SinkEventAttributeSet.CENTER);
-        expected = " decoration=boxed align=center";
+        expected = " decoration=source align=center";
         assertEquals(expected, sinkEventAttributeSet.toString());
     }
 }
diff --git a/doxia-core/src/test/java/org/apache/maven/doxia/sink/impl/SinkTestDocument.java b/doxia-core/src/test/java/org/apache/maven/doxia/sink/impl/SinkTestDocument.java
index 4c97c80f..52fbfab0 100644
--- a/doxia-core/src/test/java/org/apache/maven/doxia/sink/impl/SinkTestDocument.java
+++ b/doxia-core/src/test/java/org/apache/maven/doxia/sink/impl/SinkTestDocument.java
@@ -100,8 +100,8 @@ public class SinkTestDocument {
 
         generateList(sink);
 
-        sink.verbatim(SinkEventAttributeSet.BOXED);
-        sink.text("Verbatim text not contained in list item 3");
+        sink.verbatim(SinkEventAttributeSet.SOURCE);
+        sink.text("Verbatim source text not contained in list item 3");
         sink.verbatim_();
 
         generateNumberedList(sink);
@@ -277,8 +277,8 @@ public class SinkTestDocument {
         sink.definedTerm_();
         sink.definition();
         sink.text("of definition list.");
-        sink.verbatim(SinkEventAttributeSet.BOXED);
-        sink.text("Verbatim text" + eol + "                        in a box        ");
+        sink.verbatim(SinkEventAttributeSet.SOURCE);
+        sink.text("Verbatim source text" + eol + "                        in a box        ");
         sink.verbatim_();
         sink.definition_();
         sink.definitionListItem_();
diff --git a/doxia-core/src/test/java/org/apache/maven/doxia/sink/impl/SinkUtilsTest.java b/doxia-core/src/test/java/org/apache/maven/doxia/sink/impl/SinkUtilsTest.java
index 0717d29f..b1cbbc5b 100644
--- a/doxia-core/src/test/java/org/apache/maven/doxia/sink/impl/SinkUtilsTest.java
+++ b/doxia-core/src/test/java/org/apache/maven/doxia/sink/impl/SinkUtilsTest.java
@@ -58,14 +58,14 @@ public class SinkUtilsTest {
     public void testGetAttributeString() {
         assertEquals("", SinkUtils.getAttributeString(null));
 
-        AttributeSet att = new SinkEventAttributeSet(SinkEventAttributeSet.BOXED);
-        String expResult = " decoration=\"boxed\"";
+        AttributeSet att = new SinkEventAttributeSet(SinkEventAttributeSet.SOURCE);
+        String expResult = " decoration=\"source\"";
         String result = SinkUtils.getAttributeString(att);
         assertEquals(expResult, result);
 
         SinkEventAttributes at = new SinkEventAttributeSet(SinkEventAttributeSet.BOLD);
         at.addAttributes(att);
-        expResult = " style=\"bold\" decoration=\"boxed\"";
+        expResult = " style=\"bold\" decoration=\"source\"";
         result = SinkUtils.getAttributeString(at);
         assertEquals(expResult, result);
 
diff --git a/doxia-core/src/test/java/org/apache/maven/doxia/sink/impl/TextSink.java b/doxia-core/src/test/java/org/apache/maven/doxia/sink/impl/TextSink.java
index 127aede6..86b0fd6b 100644
--- a/doxia-core/src/test/java/org/apache/maven/doxia/sink/impl/TextSink.java
+++ b/doxia-core/src/test/java/org/apache/maven/doxia/sink/impl/TextSink.java
@@ -826,16 +826,16 @@ public class TextSink extends AbstractSink {
 
     @Override
     public void verbatim(SinkEventAttributes attributes) {
-        boolean boxed = false;
+        boolean source = false;
 
         if (attributes != null && attributes.isDefined(SinkEventAttributes.DECORATION)) {
-            boxed = "boxed"
+            source = "source"
                     .equals(attributes
                             .getAttribute(SinkEventAttributes.DECORATION)
                             .toString());
         }
 
-        write("begin:verbatim, boxed: " + boxed);
+        write("begin:verbatim, source: " + source);
     }
 
     @Override
diff --git a/doxia-core/src/test/java/org/apache/maven/doxia/sink/impl/Xhtml5BaseSinkTest.java b/doxia-core/src/test/java/org/apache/maven/doxia/sink/impl/Xhtml5BaseSinkTest.java
index 221338d1..bf650fb1 100644
--- a/doxia-core/src/test/java/org/apache/maven/doxia/sink/impl/Xhtml5BaseSinkTest.java
+++ b/doxia-core/src/test/java/org/apache/maven/doxia/sink/impl/Xhtml5BaseSinkTest.java
@@ -827,31 +827,32 @@ public class Xhtml5BaseSinkTest {
      * Test of verbatim method, of class Xhtml5BaseSink.
      */
     @Test
-    public void testVerbatim() {
+    public void testVerbatimSource() {
         try {
             sink = new Xhtml5BaseSink(writer);
 
-            sink.verbatim(SinkEventAttributeSet.BOXED);
+            sink.verbatim(SinkEventAttributeSet.SOURCE);
             sink.verbatim_();
         } finally {
             sink.close();
         }
 
-        assertEquals("<div class=\"source\">" + LS + "<pre></pre></div>", writer.toString());
+        assertEquals("<div class=\"verbatim source\">" + LS + "<pre></pre></div>", writer.toString());
 
-        checkVerbatimAttributes(attributes, "<div>" + LS + "<pre style=\"bold\"></pre></div>");
+        checkVerbatimAttributes(attributes, "<div class=\"verbatim\">" + LS + "<pre style=\"bold\"></pre></div>");
 
         final SinkEventAttributes att = new SinkEventAttributeSet(SinkEventAttributes.ID, "id");
-        checkVerbatimAttributes(att, "<div>" + LS + "<pre id=\"id\"></pre></div>");
+        checkVerbatimAttributes(att, "<div class=\"verbatim\">" + LS + "<pre id=\"id\"></pre></div>");
 
         att.addAttribute(Attribute.CLASS, "class");
-        checkVerbatimAttributes(att, "<div>" + LS + "<pre id=\"id\" class=\"class\"></pre></div>");
+        checkVerbatimAttributes(att, "<div class=\"verbatim\">" + LS + "<pre id=\"id\" class=\"class\"></pre></div>");
 
-        att.addAttribute(SinkEventAttributes.DECORATION, "boxed");
-        checkVerbatimAttributes(att, "<div class=\"source\">" + LS + "<pre id=\"id\" class=\"class\"></pre></div>");
+        att.addAttribute(SinkEventAttributes.DECORATION, "source");
+        checkVerbatimAttributes(
+                att, "<div class=\"verbatim source\">" + LS + "<pre id=\"id\" class=\"class\"></pre></div>");
 
         att.removeAttribute(Attribute.CLASS.toString());
-        checkVerbatimAttributes(att, "<div class=\"source\">" + LS + "<pre id=\"id\"></pre></div>");
+        checkVerbatimAttributes(att, "<div class=\"verbatim source\">" + LS + "<pre id=\"id\"></pre></div>");
     }
 
     private void checkVerbatimAttributes(final SinkEventAttributes att, final String expected) {
diff --git a/doxia-modules/doxia-module-apt/src/main/java/org/apache/maven/doxia/module/apt/AptParser.java b/doxia-modules/doxia-module-apt/src/main/java/org/apache/maven/doxia/module/apt/AptParser.java
index eb85cf49..847552a4 100644
--- a/doxia-modules/doxia-module-apt/src/main/java/org/apache/maven/doxia/module/apt/AptParser.java
+++ b/doxia-modules/doxia-module-apt/src/main/java/org/apache/maven/doxia/module/apt/AptParser.java
@@ -1856,8 +1856,8 @@ public class AptParser extends AbstractTextParser implements AptMarkup {
 
     /** A Verbatim Block. */
     private class Verbatim extends Block {
-        /** boxed. */
-        private boolean boxed;
+        /** source. */
+        private boolean source;
 
         /**
          * Constructor.
@@ -1873,7 +1873,7 @@ public class AptParser extends AbstractTextParser implements AptMarkup {
 
             StringBuilder buffer = new StringBuilder();
             char firstChar = firstLine.charAt(0);
-            boxed = (firstChar == PLUS);
+            source = (firstChar == PLUS);
 
             while (AptParser.this.line != null) {
                 String l = AptParser.this.line;
@@ -1927,7 +1927,7 @@ public class AptParser extends AbstractTextParser implements AptMarkup {
 
         /** {@inheritDoc} */
         public void traverse() throws AptParseException {
-            AptParser.this.sink.verbatim(boxed ? SinkEventAttributeSet.BOXED : null);
+            AptParser.this.sink.verbatim(source ? SinkEventAttributeSet.SOURCE : null);
             AptParser.this.sink.text(text);
             AptParser.this.sink.verbatim_();
         }
diff --git a/doxia-modules/doxia-module-apt/src/main/java/org/apache/maven/doxia/module/apt/AptSink.java b/doxia-modules/doxia-module-apt/src/main/java/org/apache/maven/doxia/module/apt/AptSink.java
index 275c15f9..5f0ea4da 100644
--- a/doxia-modules/doxia-module-apt/src/main/java/org/apache/maven/doxia/module/apt/AptSink.java
+++ b/doxia-modules/doxia-module-apt/src/main/java/org/apache/maven/doxia/module/apt/AptSink.java
@@ -104,8 +104,8 @@ public class AptSink extends AbstractTextSink implements AptMarkup {
     /**  verbatimFlag. */
     private boolean verbatimFlag;
 
-    /**  boxed verbatim. */
-    private boolean isBoxed;
+    /**  verbatim source. */
+    private boolean isSource;
 
     /**  gridFlag for tables. */
     private boolean gridFlag;
@@ -187,7 +187,7 @@ public class AptSink extends AbstractTextSink implements AptMarkup {
         this.bufferFlag = false;
         this.itemFlag = false;
         this.verbatimFlag = false;
-        this.isBoxed = false;
+        this.isSource = false;
         this.gridFlag = false;
         this.cellCount = 0;
         this.cellJustif = null;
@@ -585,20 +585,20 @@ public class AptSink extends AbstractTextSink implements AptMarkup {
     public void verbatim(SinkEventAttributes attributes) {
         MutableAttributeSet atts = SinkUtils.filterAttributes(attributes, SinkUtils.SINK_VERBATIM_ATTRIBUTES);
 
-        boolean boxed = false;
+        boolean source = false;
 
         if (atts != null && atts.isDefined(SinkEventAttributes.DECORATION)) {
-            boxed = "boxed"
+            source = "source"
                     .equals(atts.getAttribute(SinkEventAttributes.DECORATION).toString());
         }
 
         verbatimFlag = true;
-        this.isBoxed = boxed;
+        this.isSource = source;
         write(EOL);
-        if (boxed) {
-            write(EOL + BOXED_VERBATIM_START_MARKUP + EOL);
+        if (source) {
+            write(EOL + VERBATIM_SOURCE_START_MARKUP + EOL);
         } else {
-            write(EOL + NON_BOXED_VERBATIM_START_MARKUP + EOL);
+            write(EOL + VERBATIM_START_MARKUP + EOL);
         }
     }
 
@@ -606,12 +606,12 @@ public class AptSink extends AbstractTextSink implements AptMarkup {
      * {@inheritDoc}
      */
     public void verbatim_() {
-        if (isBoxed) {
-            write(EOL + BOXED_VERBATIM_END_MARKUP + EOL);
+        if (isSource) {
+            write(EOL + VERBATIM_SOURCE_END_MARKUP + EOL);
         } else {
-            write(EOL + NON_BOXED_VERBATIM_END_MARKUP + EOL);
+            write(EOL + VERBATIM_END_MARKUP + EOL);
         }
-        isBoxed = false;
+        isSource = false;
         verbatimFlag = false;
     }
 
diff --git a/doxia-modules/doxia-module-apt/src/test/java/org/apache/maven/doxia/module/apt/AptParserTest.java b/doxia-modules/doxia-module-apt/src/test/java/org/apache/maven/doxia/module/apt/AptParserTest.java
index ec1dae50..4ce0615c 100644
--- a/doxia-modules/doxia-module-apt/src/test/java/org/apache/maven/doxia/module/apt/AptParserTest.java
+++ b/doxia-modules/doxia-module-apt/src/test/java/org/apache/maven/doxia/module/apt/AptParserTest.java
@@ -183,9 +183,9 @@ public class AptParserTest extends AbstractParserTest {
     }
 
     @Test
-    public void testBoxedVerbatim() throws Exception {
-        String text = "+--" + EOL + "boxed verbatim" + EOL + "+--" + EOL + "---" + EOL + "un-boxed verbatim" + EOL
-                + "---" + EOL;
+    public void testVerbatimSource() throws Exception {
+        String text =
+                "+--" + EOL + "verbatim source" + EOL + "+--" + EOL + "---" + EOL + "verbatim" + EOL + "---" + EOL;
 
         SinkEventTestingSink sink = new SinkEventTestingSink();
 
@@ -194,7 +194,7 @@ public class AptParserTest extends AbstractParserTest {
         Iterator<SinkEventElement> it = sink.getEventList().iterator();
 
         assertSinkStartsWith(it, "head", "head_", "body");
-        assertSinkEquals(it.next(), "verbatim", SinkEventAttributeSet.BOXED);
+        assertSinkEquals(it.next(), "verbatim", SinkEventAttributeSet.SOURCE);
         assertSinkStartsWith(it, "text", "verbatim_");
 
         assertSinkEquals(it.next(), "verbatim", new Object[] {null});
diff --git a/doxia-modules/doxia-module-apt/src/test/java/org/apache/maven/doxia/module/apt/AptSinkTest.java b/doxia-modules/doxia-module-apt/src/test/java/org/apache/maven/doxia/module/apt/AptSinkTest.java
index 0c96895d..fd71ab84 100644
--- a/doxia-modules/doxia-module-apt/src/test/java/org/apache/maven/doxia/module/apt/AptSinkTest.java
+++ b/doxia-modules/doxia-module-apt/src/test/java/org/apache/maven/doxia/module/apt/AptSinkTest.java
@@ -237,14 +237,14 @@ public class AptSinkTest extends AbstractSinkTest {
     }
 
     /** {@inheritDoc} */
-    protected String getVerbatimBlock(String text) {
+    protected String getVerbatimSourceBlock(String text) {
         return EOL
                 + EOL
-                + AptMarkup.BOXED_VERBATIM_START_MARKUP
+                + AptMarkup.VERBATIM_SOURCE_START_MARKUP
                 + EOL
                 + text
                 + EOL
-                + AptMarkup.BOXED_VERBATIM_START_MARKUP
+                + AptMarkup.VERBATIM_SOURCE_START_MARKUP
                 + EOL;
     }
 
diff --git a/doxia-modules/doxia-module-fml/src/main/java/org/apache/maven/doxia/module/fml/FmlContentParser.java b/doxia-modules/doxia-module-fml/src/main/java/org/apache/maven/doxia/module/fml/FmlContentParser.java
index 987a5b87..ab24de1f 100644
--- a/doxia-modules/doxia-module-fml/src/main/java/org/apache/maven/doxia/module/fml/FmlContentParser.java
+++ b/doxia-modules/doxia-module-fml/src/main/java/org/apache/maven/doxia/module/fml/FmlContentParser.java
@@ -71,7 +71,7 @@ public class FmlContentParser extends Xhtml5BaseParser implements FmlMarkup {
         } else if (parser.getName().equals(SOURCE_TAG.toString())) {
             verbatim();
 
-            sink.verbatim(SinkEventAttributeSet.BOXED);
+            sink.verbatim(SinkEventAttributeSet.SOURCE);
         } else if (!baseStartTag(parser, sink)) {
             if (isEmptyElement) {
                 handleUnknown(parser, sink, TAG_TYPE_SIMPLE);
diff --git a/doxia-modules/doxia-module-markdown/src/main/java/org/apache/maven/doxia/module/markdown/MarkdownMarkup.java b/doxia-modules/doxia-module-markdown/src/main/java/org/apache/maven/doxia/module/markdown/MarkdownMarkup.java
index 8a119aaa..f72fe03c 100644
--- a/doxia-modules/doxia-module-markdown/src/main/java/org/apache/maven/doxia/module/markdown/MarkdownMarkup.java
+++ b/doxia-modules/doxia-module-markdown/src/main/java/org/apache/maven/doxia/module/markdown/MarkdownMarkup.java
@@ -119,8 +119,8 @@ public interface MarkdownMarkup extends TextMarkup {
     /** Syntax for the mono-spaced style start: "`" */
     String MONOSPACED_START_MARKUP = "`";
 
-    /** Syntax for the non boxed verbatim start: "```" */
-    String NON_BOXED_VERBATIM_START_MARKUP = "```";
+    /** Syntax for the verbatim start: "```" */
+    String VERBATIM_START_MARKUP = "```";
 
     /** Syntax for the non breaking space: "\ " */
     String NON_BREAKING_SPACE_MARKUP = String.valueOf(BACKSLASH) + SPACE;
@@ -146,6 +146,6 @@ public interface MarkdownMarkup extends TextMarkup {
     /** Syntax for the table row end: "|" */
     String TABLE_ROW_SEPARATOR_MARKUP = String.valueOf(PIPE);
 
-    /** Syntax for the non boxed verbatim end: "```" */
-    String NON_BOXED_VERBATIM_END_MARKUP = "```";
+    /** Syntax for the verbatim end: "```" */
+    String VERBATIM_END_MARKUP = "```";
 }
diff --git a/doxia-modules/doxia-module-markdown/src/main/java/org/apache/maven/doxia/module/markdown/MarkdownParser.java b/doxia-modules/doxia-module-markdown/src/main/java/org/apache/maven/doxia/module/markdown/MarkdownParser.java
index c1cb3521..26156d33 100644
--- a/doxia-modules/doxia-module-markdown/src/main/java/org/apache/maven/doxia/module/markdown/MarkdownParser.java
+++ b/doxia-modules/doxia-module-markdown/src/main/java/org/apache/maven/doxia/module/markdown/MarkdownParser.java
@@ -263,9 +263,8 @@ public class MarkdownParser extends AbstractTextParser implements TextMarkup {
      * 2 special things:
      * <ul>
      * <li> DIV elements are translated as Unknown Sink events
-     * <li> PRE elements are all considered as boxed
      * </ul>
-     * PRE elements need to be "boxed" because the Xhtml5Sink will surround the
+     * PRE elements need to be "source" because the Xhtml5Sink will surround the
      * corresponding verbatim() Sink event with a DIV element with class="source",
      * which is how most Maven Skin (incl. Fluido) recognize a block of code, which
      * needs to be highlighted accordingly.
@@ -279,7 +278,6 @@ public class MarkdownParser extends AbstractTextParser implements TextMarkup {
         @Override
         protected void init() {
             super.init();
-            super.boxed = true;
         }
 
         @Override
@@ -300,7 +298,6 @@ public class MarkdownParser extends AbstractTextParser implements TextMarkup {
             if (!visited) {
                 if (parser.getName().equals(HtmlMarkup.DIV.toString())) {
                     handleUnknown(parser, sink, TAG_TYPE_START);
-                    super.boxed = true;
                     visited = true;
                 }
             }
diff --git a/doxia-modules/doxia-module-markdown/src/main/java/org/apache/maven/doxia/module/markdown/MarkdownSink.java b/doxia-modules/doxia-module-markdown/src/main/java/org/apache/maven/doxia/module/markdown/MarkdownSink.java
index 5229bc52..57995b0e 100644
--- a/doxia-modules/doxia-module-markdown/src/main/java/org/apache/maven/doxia/module/markdown/MarkdownSink.java
+++ b/doxia-modules/doxia-module-markdown/src/main/java/org/apache/maven/doxia/module/markdown/MarkdownSink.java
@@ -561,14 +561,14 @@ public class MarkdownSink extends AbstractTextSink implements MarkdownMarkup {
     public void verbatim(SinkEventAttributes attributes) {
         write(EOL);
         verbatimFlag = true;
-        write(EOL + NON_BOXED_VERBATIM_START_MARKUP + EOL);
+        write(EOL + VERBATIM_START_MARKUP + EOL);
     }
 
     /**
      * {@inheritDoc}
      */
     public void verbatim_() {
-        write(EOL + NON_BOXED_VERBATIM_END_MARKUP + EOL);
+        write(EOL + VERBATIM_END_MARKUP + EOL);
         verbatimFlag = false;
     }
 
diff --git a/doxia-modules/doxia-module-markdown/src/test/java/org/apache/maven/doxia/module/markdown/MarkdownParserTest.java b/doxia-modules/doxia-module-markdown/src/test/java/org/apache/maven/doxia/module/markdown/MarkdownParserTest.java
index 92e8be94..64d15488 100644
--- a/doxia-modules/doxia-module-markdown/src/test/java/org/apache/maven/doxia/module/markdown/MarkdownParserTest.java
+++ b/doxia-modules/doxia-module-markdown/src/test/java/org/apache/maven/doxia/module/markdown/MarkdownParserTest.java
@@ -225,11 +225,11 @@ public class MarkdownParserTest extends AbstractParserTest {
         assertFalse(it.hasNext());
 
         // PRE element must be a "verbatim" Sink event that specifies
-        // BOXED = true
+        // SOURCE = true
         SinkEventElement pre = eventList.get(7);
         assertEquals("verbatim", pre.getName());
         SinkEventAttributeSet preAtts = (SinkEventAttributeSet) pre.getArgs()[0];
-        assertTrue(preAtts.containsAttribute(SinkEventAttributes.DECORATION, "boxed"));
+        assertFalse(preAtts.containsAttribute(SinkEventAttributes.DECORATION, "source"));
 
         // * CODE element must be an "inline" Sink event that specifies:
         // * SEMANTICS = "code" and CLASS = "language-java"
diff --git a/doxia-modules/doxia-module-markdown/src/test/java/org/apache/maven/doxia/module/markdown/MarkdownSinkTest.java b/doxia-modules/doxia-module-markdown/src/test/java/org/apache/maven/doxia/module/markdown/MarkdownSinkTest.java
index 8381ac77..aed2670c 100644
--- a/doxia-modules/doxia-module-markdown/src/test/java/org/apache/maven/doxia/module/markdown/MarkdownSinkTest.java
+++ b/doxia-modules/doxia-module-markdown/src/test/java/org/apache/maven/doxia/module/markdown/MarkdownSinkTest.java
@@ -228,14 +228,14 @@ public class MarkdownSinkTest extends AbstractSinkTest {
     }
 
     /** {@inheritDoc} */
-    protected String getVerbatimBlock(String text) {
+    protected String getVerbatimSourceBlock(String text) {
         return EOL
                 + EOL
-                + MarkdownMarkup.NON_BOXED_VERBATIM_START_MARKUP
+                + MarkdownMarkup.VERBATIM_START_MARKUP
                 + EOL
                 + text
                 + EOL
-                + MarkdownMarkup.NON_BOXED_VERBATIM_START_MARKUP
+                + MarkdownMarkup.VERBATIM_START_MARKUP
                 + EOL;
     }
 
diff --git a/doxia-modules/doxia-module-xdoc/src/main/java/org/apache/maven/doxia/module/xdoc/XdocParser.java b/doxia-modules/doxia-module-xdoc/src/main/java/org/apache/maven/doxia/module/xdoc/XdocParser.java
index a1a08736..ef8414b9 100644
--- a/doxia-modules/doxia-module-xdoc/src/main/java/org/apache/maven/doxia/module/xdoc/XdocParser.java
+++ b/doxia-modules/doxia-module-xdoc/src/main/java/org/apache/maven/doxia/module/xdoc/XdocParser.java
@@ -177,7 +177,7 @@ public class XdocParser extends Xhtml5BaseParser implements XdocMarkup {
         } else if (parser.getName().equals(SOURCE_TAG.toString())) {
             verbatim();
 
-            attribs.addAttributes(SinkEventAttributeSet.BOXED);
+            attribs.addAttributes(SinkEventAttributeSet.SOURCE);
 
             sink.verbatim(attribs);
         } else if (parser.getName().equals(PROPERTIES_TAG.toString())) {
diff --git a/doxia-modules/doxia-module-xdoc/src/test/java/org/apache/maven/doxia/module/xdoc/XdocSinkTest.java b/doxia-modules/doxia-module-xdoc/src/test/java/org/apache/maven/doxia/module/xdoc/XdocSinkTest.java
index 227c6527..fae215d3 100644
--- a/doxia-modules/doxia-module-xdoc/src/test/java/org/apache/maven/doxia/module/xdoc/XdocSinkTest.java
+++ b/doxia-modules/doxia-module-xdoc/src/test/java/org/apache/maven/doxia/module/xdoc/XdocSinkTest.java
@@ -258,7 +258,7 @@ public class XdocSinkTest extends AbstractSinkTest {
     }
 
     /** {@inheritDoc} */
-    protected String getVerbatimBlock(String text) {
+    protected String getVerbatimSourceBlock(String text) {
         return "<source>" + text + "</source>";
     }
 
@@ -347,7 +347,7 @@ public class XdocSinkTest extends AbstractSinkTest {
      * Test verbatim.
      */
     @Test
-    public void testBoxedVerbatim() {
+    public void testVerbatimSource() {
         Writer writer = new StringWriter();
         XdocSink sink = null;
 
@@ -356,7 +356,7 @@ public class XdocSinkTest extends AbstractSinkTest {
 
             sink.verbatim(null);
             sink.verbatim_();
-            sink.verbatim(SinkEventAttributeSet.BOXED);
+            sink.verbatim(SinkEventAttributeSet.SOURCE);
             sink.verbatim_();
         } finally {
             sink.close();
diff --git a/doxia-modules/doxia-module-xhtml5/src/main/java/org/apache/maven/doxia/module/xhtml5/Xhtml5Parser.java b/doxia-modules/doxia-module-xhtml5/src/main/java/org/apache/maven/doxia/module/xhtml5/Xhtml5Parser.java
index fd33c499..ed78b597 100644
--- a/doxia-modules/doxia-module-xhtml5/src/main/java/org/apache/maven/doxia/module/xhtml5/Xhtml5Parser.java
+++ b/doxia-modules/doxia-module-xhtml5/src/main/java/org/apache/maven/doxia/module/xhtml5/Xhtml5Parser.java
@@ -70,8 +70,8 @@ import org.slf4j.LoggerFactory;
 public class Xhtml5Parser extends Xhtml5BaseParser implements Xhtml5Markup {
     private static final Logger LOGGER = LoggerFactory.getLogger(Xhtml5Parser.class);
 
-    /** For boxed verbatim. */
-    protected boolean boxed;
+    /** For verbatim source. */
+    protected boolean source;
 
     /** Empty elements don't write a closing tag. */
     private boolean isEmptyElement;
@@ -125,10 +125,10 @@ public class Xhtml5Parser extends Xhtml5BaseParser implements Xhtml5Markup {
         } else if (parser.getName().equals(BODY.toString())) {
             sink.body(attribs);
         } else if (parser.getName().equals(DIV.toString())) {
-            String divclass = parser.getAttributeValue(null, Attribute.CLASS.toString());
+            String divClass = parser.getAttributeValue(null, Attribute.CLASS.toString());
 
-            if ("source".equals(divclass)) {
-                this.boxed = true;
+            if ("verbatim source".equals(divClass)) {
+                this.source = true;
             }
 
             baseStartTag(parser, sink); // pick up other divs
@@ -144,8 +144,8 @@ public class Xhtml5Parser extends Xhtml5BaseParser implements Xhtml5Markup {
          * in the content of a PRE element.
          */
         else if (parser.getName().equals(PRE.toString())) {
-            if (boxed) {
-                attribs.addAttributes(SinkEventAttributeSet.BOXED);
+            if (source) {
+                attribs.addAttributes(SinkEventAttributeSet.SOURCE);
             }
 
             verbatim();
@@ -183,7 +183,7 @@ public class Xhtml5Parser extends Xhtml5BaseParser implements Xhtml5Markup {
         } else if (parser.getName().equals(ADDRESS.toString())) {
             sink.address_();
         } else if (parser.getName().equals(DIV.toString())) {
-            this.boxed = false;
+            this.source = false;
             baseEndTag(parser, sink);
         } else if (!baseEndTag(parser, sink)) {
             if (!isEmptyElement) {
@@ -282,7 +282,7 @@ public class Xhtml5Parser extends Xhtml5BaseParser implements Xhtml5Markup {
     protected void init() {
         super.init();
 
-        this.boxed = false;
+        this.source = false;
         this.isEmptyElement = false;
     }
 
diff --git a/doxia-modules/doxia-module-xhtml5/src/test/java/org/apache/maven/doxia/module/xhtml5/Xhtml5SinkTest.java b/doxia-modules/doxia-module-xhtml5/src/test/java/org/apache/maven/doxia/module/xhtml5/Xhtml5SinkTest.java
index 82df0d94..e91138eb 100644
--- a/doxia-modules/doxia-module-xhtml5/src/test/java/org/apache/maven/doxia/module/xhtml5/Xhtml5SinkTest.java
+++ b/doxia-modules/doxia-module-xhtml5/src/test/java/org/apache/maven/doxia/module/xhtml5/Xhtml5SinkTest.java
@@ -254,8 +254,8 @@ public class Xhtml5SinkTest extends AbstractSinkTest {
     }
 
     /** {@inheritDoc} */
-    protected String getVerbatimBlock(String text) {
-        return "<div class=\"source\">\n<pre>" + text + "</pre></div>";
+    protected String getVerbatimSourceBlock(String text) {
+        return "<div class=\"verbatim source\">\n<pre>" + text + "</pre></div>";
     }
 
     /** {@inheritDoc} */
diff --git a/doxia-sink-api/src/main/java/org/apache/maven/doxia/sink/Sink.java b/doxia-sink-api/src/main/java/org/apache/maven/doxia/sink/Sink.java
index 38378c36..f731f351 100644
--- a/doxia-sink-api/src/main/java/org/apache/maven/doxia/sink/Sink.java
+++ b/doxia-sink-api/src/main/java/org/apache/maven/doxia/sink/Sink.java
@@ -1360,7 +1360,7 @@ public interface Sink {
      *   Supported attributes are the {@link SinkEventAttributes base attributes} plus:
      * </p>
      * <blockquote>
-     *   {@link SinkEventAttributes#DECORATION DECORATION} (value: "boxed"),
+     *   {@link SinkEventAttributes#DECORATION DECORATION} (values: "source"),
      *   {@link SinkEventAttributes#ALIGN ALIGN}, {@link SinkEventAttributes#WIDTH WIDTH}.
      * </blockquote>
      *
diff --git a/doxia-sink-api/src/main/java/org/apache/maven/doxia/sink/SinkEventAttributes.java b/doxia-sink-api/src/main/java/org/apache/maven/doxia/sink/SinkEventAttributes.java
index ac701b93..b7fe9489 100644
--- a/doxia-sink-api/src/main/java/org/apache/maven/doxia/sink/SinkEventAttributes.java
+++ b/doxia-sink-api/src/main/java/org/apache/maven/doxia/sink/SinkEventAttributes.java
@@ -369,7 +369,7 @@ public interface SinkEventAttributes extends MutableAttributeSet {
      * Specifies a decoration for an element.
      *
      * <p>
-     *   Generally accepted values are "underline", "overline", "line-through", "boxed".
+     *   Generally accepted values are "underline", "overline", "line-through", "source".
      * </p>
      */
     String DECORATION = "decoration";
diff --git a/doxia-core/src/main/java/org/apache/maven/doxia/macro/snippet/SnippetMacro.java b/doxia-core/src/main/java/org/apache/maven/doxia/macro/snippet/SnippetMacro.java
index b5e4b231..66f30827 100644
--- a/doxia-core/src/main/java/org/apache/maven/doxia/macro/snippet/SnippetMacro.java
+++ b/doxia-core/src/main/java/org/apache/maven/doxia/macro/snippet/SnippetMacro.java
@@ -57,7 +57,7 @@ import org.slf4j.Logger;
 import org.slf4j.LoggerFactory;
 
 /**
  * A macro that prints out the content of a file or a URL.
  */
 @Singleton
 @Named("snippet")
@@ -119,6 +119,14 @@ public class SnippetMacro extends AbstractMacro {
             verbatim = Boolean.valueOf(verbatimParam);
         }
 
+        boolean source = true;
+
+        String sourceParam = (String) request.getParameter("source");
+
+        if (sourceParam != null && !"".equals(sourceParam)) {
+            source = Boolean.valueOf(sourceParam);
+        }
+
         String encoding = (String) request.getParameter("encoding");
 
         URL url;
@@ -154,7 +162,7 @@ public class SnippetMacro extends AbstractMacro {
         }
 
         if (verbatim) {
-            sink.verbatim(SinkEventAttributeSet.BOXED);
+            sink.verbatim(source ? SinkEventAttributeSet.SOURCE : null);
 
             sink.text(snippet.toString());
 
@@ -57,7 +57,7 @@ import org.slf4j.Logger;
 
 /**
- * A macro that prints out the content of a file or a URL.
+ * A macro that prints out the (source code) content of a file or a URL.
  */
 @Singleton
diff --git a/doxia-core/src/main/java/org/apache/maven/doxia/sink/impl/Xhtml5BaseSink.java b/doxia-core/src/main/java/org/apache/maven/doxia/sink/impl/Xhtml5BaseSink.java
index eb04738a..36edb3df 100644
--- a/doxia-core/src/main/java/org/apache/maven/doxia/sink/impl/Xhtml5BaseSink.java
+++ b/doxia-core/src/main/java/org/apache/maven/doxia/sink/impl/Xhtml5BaseSink.java
@@ -1124,7 +1124,7 @@ public class Xhtml5BaseSink extends AbstractXmlSink implements HtmlMarkup {
     }
 
     /**
      * The default class style for boxed is <code>source</code>.
      *
      * {@inheritDoc}
      * @see javax.swing.text.html.HTML.Tag#DIV
@@ -1147,19 +1147,22 @@ public class Xhtml5BaseSink extends AbstractXmlSink implements HtmlMarkup {
             atts = new SinkEventAttributeSet();
         }
 
-        boolean boxed = false;
+        boolean source = false;
 
         if (atts.isDefined(SinkEventAttributes.DECORATION)) {
-            boxed = "boxed"
+            source = "source"
                     .equals(atts.getAttribute(SinkEventAttributes.DECORATION).toString());
         }
 
         SinkEventAttributes divAtts = null;
+        String divClass = "verbatim";
 
-        if (boxed) {
-            divAtts = new SinkEventAttributeSet(Attribute.CLASS.toString(), "source");
+        if (source) {
+            divClass += " source";
         }
 
+        divAtts = new SinkEventAttributeSet(Attribute.CLASS.toString(), divClass);
+
         atts.removeAttribute(SinkEventAttributes.DECORATION);
 
         writeStartTag(HtmlMarkup.DIV, divAtts);
@@ -1124,7 +1124,7 @@ public class Xhtml5BaseSink extends AbstractXmlSink implements HtmlMarkup {
 
     /**
-     * The default class style for boxed is <code>source</code>.
+     * The default class style is <code>verbatim</code>, for source is {@code verbatim source}.
      *
      * {@inheritDoc}
diff --git a/doxia-core/src/test/java/org/apache/maven/doxia/sink/impl/AbstractSinkTest.java b/doxia-core/src/test/java/org/apache/maven/doxia/sink/impl/AbstractSinkTest.java
index 3c34d49a..9be0f353 100644
--- a/doxia-core/src/test/java/org/apache/maven/doxia/sink/impl/AbstractSinkTest.java
+++ b/doxia-core/src/test/java/org/apache/maven/doxia/sink/impl/AbstractSinkTest.java
@@ -134,9 +134,9 @@ public abstract class AbstractSinkTest extends AbstractModuleTest {
     }
 
     /**
-     * Checks that the sequence <code>[title(), text( title ), title_()]</code>,
+     * Checks that the sequence <code>[title(), text(title), title_()]</code>,
      * invoked on the current sink, produces the same result as
-     * {@link #getTitleBlock getTitleBlock}( title ).
+     * {@link #getTitleBlock getTitleBlock}(title).
      */
     @Test
     public void testTitle() {
@@ -154,9 +154,9 @@ public abstract class AbstractSinkTest extends AbstractModuleTest {
     }
 
     /**
-     * Checks that the sequence <code>[author(), text( author ), author_()]
+     * Checks that the sequence <code>[author(), text(author), author_()]
      * </code>, invoked on the current sink, produces the same result as
-     * {@link #getAuthorBlock getAuthorBlock}( author ).
+     * {@link #getAuthorBlock getAuthorBlock}(author).
      */
     @Test
     public void testAuthor() {
@@ -174,9 +174,9 @@ public abstract class AbstractSinkTest extends AbstractModuleTest {
     }
 
     /**
-     * Checks that the sequence <code>[date(), text( date ), date_()]</code>,
+     * Checks that the sequence <code>[date(), text(date), date_()]</code>,
      * invoked on the current sink, produces the same result as
-     * {@link #getDateBlock getDateBlock}( date ).
+     * {@link #getDateBlock getDateBlock}(date).
      */
     @Test
     public void testDate() {
@@ -284,10 +284,10 @@ public abstract class AbstractSinkTest extends AbstractModuleTest {
     }
 
     /**
-     * Checks that the sequence <code>[sectionTitle(), text( title ),
+     * Checks that the sequence <code>[sectionTitle(), text(title),
      * sectionTitle_()]</code>, invoked on the current sink, produces
      * the same result as
-     * {@link #getSectionTitleBlock getSectionTitleBlock}( title ).
+     * {@link #getSectionTitleBlock getSectionTitleBlock}(title).
      */
     @Test
     public void testSectionTitle() {
@@ -306,9 +306,9 @@ public abstract class AbstractSinkTest extends AbstractModuleTest {
 
     /**
      * Checks that the sequence <code>[section1(), sectionTitle1(),
-     * text( title ), sectionTitle1_(), section1_()]</code>,
+     * text(title), sectionTitle1_(), section1_()]</code>,
      * invoked on the current sink, produces the same result as
-     * {@link #getSection1Block getSection1Block}( title ).
+     * {@link #getSection1Block getSection1Block}(title).
      */
     @Test
     public void testSection1() {
@@ -331,9 +331,9 @@ public abstract class AbstractSinkTest extends AbstractModuleTest {
 
     /**
      * Checks that the sequence <code>[section2(), sectionTitle2(),
-     * text( title ), sectionTitle2_(), section2_()]</code>,
+     * text(title), sectionTitle2_(), section2_()]</code>,
      * invoked on the current sink, produces the same result as
-     * {@link #getSection2Block getSection2Block}( title ).
+     * {@link #getSection2Block getSection2Block}(title).
      */
     @Test
     public void testSection2() {
@@ -356,9 +356,9 @@ public abstract class AbstractSinkTest extends AbstractModuleTest {
 
     /**
      * Checks that the sequence <code>[section3(), sectionTitle3(),
-     * text( title ), sectionTitle3_(), section3_()]</code>,
+     * text(title), sectionTitle3_(), section3_()]</code>,
      * invoked on the current sink, produces the same result as
-     * {@link #getSection3Block getSection3Block}( title ).
+     * {@link #getSection3Block getSection3Block}(title).
      */
     @Test
     public void testSection3() {
@@ -381,9 +381,9 @@ public abstract class AbstractSinkTest extends AbstractModuleTest {
 
     /**
      * Checks that the sequence <code>[section4(), sectionTitle4(),
-     * text( title ), sectionTitle4_(), section4_()]</code>,
+     * text(title), sectionTitle4_(), section4_()]</code>,
      * invoked on the current sink, produces the same result as
-     * {@link #getSection4Block getSection4Block}( title ).
+     * {@link #getSection4Block getSection4Block}(title).
      *
      */
     @Test
@@ -407,9 +407,9 @@ public abstract class AbstractSinkTest extends AbstractModuleTest {
 
     /**
      * Checks that the sequence <code>[section5(), sectionTitle5(),
-     * text( title ), sectionTitle5_(), section5_()]</code>,
+     * text(title), sectionTitle5_(), section5_()]</code>,
      * invoked on the current sink, produces the same result as
-     * {@link #getSection5Block getSection5Block}( title ).
+     * {@link #getSection5Block getSection5Block}(title).
      */
     @Test
     public void testSection5() {
@@ -487,9 +487,9 @@ public abstract class AbstractSinkTest extends AbstractModuleTest {
     }
 
     /**
-     * Checks that the sequence <code>[list(), listItem(), text( item ),
+     * Checks that the sequence <code>[list(), listItem(), text(item),
      * listItem_(), list_()]</code>, invoked on the current sink, produces
-     * the same result as {@link #getListBlock getListBlock}( item ).
+     * the same result as {@link #getListBlock getListBlock}(item).
      *
      */
     @Test
@@ -511,10 +511,10 @@ public abstract class AbstractSinkTest extends AbstractModuleTest {
 
     /**
      * Checks that the sequence <code>
-     * [numberedList( Sink.NUMBERING_LOWER_ROMAN ), numberedListItem(),
-     * text( item ), numberedListItem_(), numberedList_()]</code>,
+     * [numberedList(Sink.NUMBERING_LOWER_ROMAN), numberedListItem(),
+     * text(item), numberedListItem_(), numberedList_()]</code>,
      * invoked on the current sink, produces the same result as
-     * {@link #getNumberedListBlock getNumberedListBlock}( item ).
+     * {@link #getNumberedListBlock getNumberedListBlock}(item).
      */
     @Test
     public void testNumberedList() {
@@ -535,11 +535,11 @@ public abstract class AbstractSinkTest extends AbstractModuleTest {
 
     /**
      * Checks that the sequence <code>[definitionList(), definitionListItem(),
-     * definedTerm(), text( definum ), definedTerm_(), definition(),
-     * text( definition ), definition_(), definitionListItem_(),
+     * definedTerm(), text(definum), definedTerm_(), definition(),
+     * text(definition), definition_(), definitionListItem_(),
      * definitionList_()]</code>, invoked on the current sink, produces the same
      * result as {@link #getDefinitionListBlock getDefinitionListBlock}
-     * ( definum, definition ).
+     * (definum, definition).
      */
     @Test
     public void testDefinitionList() {
@@ -565,10 +565,10 @@ public abstract class AbstractSinkTest extends AbstractModuleTest {
     }
 
     /**
-     * Checks that the sequence <code>[figure(), figureGraphics( source ),
-     * figureCaption(), text( caption ), figureCaption_(), figure_()]</code>,
+     * Checks that the sequence <code>[figure(), figureGraphics(source ),
+     * figureCaption(), text(caption), figureCaption_(), figure_()]</code>,
      * invoked on the current sink, produces the same result as
-     * {@link #getFigureBlock getFigureBlock}( source, caption ).
+     * {@link #getFigureBlock getFigureBlock}(source, caption).
      */
     @Test
     public void testFigure() {
@@ -633,11 +633,11 @@ public abstract class AbstractSinkTest extends AbstractModuleTest {
 
     /**
      * Checks that the sequence <code>[table(),
-     * tableRows( Sink.JUSTIFY_CENTER, false ), tableRow(), tableCell(),
-     * text( cell ), tableCell_(), tableRow_(), tableRows_(), tableCaption(),
-     * text( caption ), tableCaption_(), table_()]</code>,
+     * tableRows(Sink.JUSTIFY_CENTER, false), tableRow(), tableCell(),
+     * text(cell), tableCell_(), tableRow_(), tableRows_(), tableCaption(),
+     * text(caption), tableCaption_(), table_()]</code>,
      * invoked on the current sink, produces the same result as
-     * {@link #getTableBlock getTableBlock}( cell, caption ).
+     * {@link #getTableBlock getTableBlock}(cell, caption).
      */
     @Test
     public void testTable() {
@@ -670,9 +670,9 @@ public abstract class AbstractSinkTest extends AbstractModuleTest {
     }
 
     /**
-     * Checks that the sequence <code>[paragraph(), text( text ),
+     * Checks that the sequence <code>[paragraph(), text(text),
      * paragraph_()]</code>, invoked on the current sink, produces
-     * the same result as {@link #getParagraphBlock getParagraphBlock}( text ).
+     * the same result as {@link #getParagraphBlock getParagraphBlock}(text).
      */
     @Test
     public void testParagraph() {
@@ -690,9 +690,9 @@ public abstract class AbstractSinkTest extends AbstractModuleTest {
     }
 
     /**
-     * Checks that the sequence <code>[data(), text( text ),
+     * Checks that the sequence <code>[data(), text(text),
      * data_()]</code>, invoked on the current sink, produces
-     * the same result as {@link #getDataBlock getDataBlock}( text ).
+     * the same result as {@link #getDataBlock getDataBlock}(text).
      */
     @Test
     public void testData() {
@@ -711,9 +711,9 @@ public abstract class AbstractSinkTest extends AbstractModuleTest {
     }
 
     /**
-     * Checks that the sequence <code>[time(), text( text ),
+     * Checks that the sequence <code>[time(), text(text),
      * time_()]</code>, invoked on the current sink, produces
-     * the same result as {@link #getTimeBlock getTimeBlock}( text ).
+     * the same result as {@link #getTimeBlock getTimeBlock}(text).
      */
     @Test
     public void testTime() {
@@ -732,9 +732,9 @@ public abstract class AbstractSinkTest extends AbstractModuleTest {
     }
 
     /**
-     * Checks that the sequence <code>[address(), text( text ),
+     * Checks that the sequence <code>[address(), text(text),
      * address_()]</code>, invoked on the current sink, produces
-     * the same result as {@link #getAddressBlock getAddressBlock}( text ).
+     * the same result as {@link #getAddressBlock getAddressBlock}(text).
      */
     @Test
     public void testAddress() {
@@ -752,9 +752,9 @@ public abstract class AbstractSinkTest extends AbstractModuleTest {
     }
 
     /**
-     * Checks that the sequence <code>[blockquote(), text( text ),
+     * Checks that the sequence <code>[blockquote(), text(text),
      * blockquote_()]</code>, invoked on the current sink, produces
-     * the same result as {@link #getBlockquoteBlock}( text ).
+     * the same result as {@link #getBlockquoteBlock}(text).
      */
     @Test
     public void testBlockquote() {
@@ -772,9 +772,9 @@ public abstract class AbstractSinkTest extends AbstractModuleTest {
     }
 
     /**
-     * Checks that the sequence <code>[division(), text( text ),
+     * Checks that the sequence <code>[division(), text(text),
      * division_()]</code>, invoked on the current sink, produces
-     * the same result as {@link #getDivisionBlock getDivisionBlock}( text ).
+     * the same result as {@link #getDivisionBlock getDivisionBlock}(text).
      */
     @Test
     public void testDivider() {
@@ -792,21 +792,21 @@ public abstract class AbstractSinkTest extends AbstractModuleTest {
     }
 
     /**
      * Checks that the sequence <code>[verbatim( SinkEventAttributeSet.BOXED ), text( text ),
      * verbatim_()]</code>, invoked on the current sink, produces the
      * same result as {@link #getVerbatimBlock getVerbatimBlock}( text ).
      */
     @Test
-    public void testVerbatim() {
+    public void testVerbatimSource() {
         String text = "Text";
-        sink.verbatim(SinkEventAttributeSet.BOXED);
+        sink.verbatim(SinkEventAttributeSet.SOURCE);
         sink.text(text);
         sink.verbatim_();
         sink.flush();
         sink.close();
 
         String actual = testWriter.toString();
-        String expected = getVerbatimBlock(text);
+        String expected = getVerbatimSourceBlock(text);
 
         assertEquals(expected, actual, "Wrong verbatim!");
     }
@@ -846,9 +846,9 @@ public abstract class AbstractSinkTest extends AbstractModuleTest {
     }
 
     /**
-     * Checks that the sequence <code>[anchor( anchor ), text( anchor ),
+     * Checks that the sequence <code>[anchor(anchor), text(anchor),
      * anchor_()]</code>, invoked on the current sink, produces the same
-     * result as {@link #getAnchorBlock getAnchorBlock}( anchor ).
+     * result as {@link #getAnchorBlock getAnchorBlock}(anchor).
      */
     @Test
     public void testAnchor() {
@@ -866,9 +866,9 @@ public abstract class AbstractSinkTest extends AbstractModuleTest {
     }
 
     /**
-     * Checks that the sequence <code>[link( link ), text( text ),
+     * Checks that the sequence <code>[link(link), text(text),
      * link_()]</code>, invoked on the current sink, produces the same
-     * result as {@link #getLinkBlock getLinkBlock}( link, text ).
+     * result as {@link #getLinkBlock getLinkBlock}(link, text).
      */
     @Test
     public void testLink() {
@@ -887,9 +887,9 @@ public abstract class AbstractSinkTest extends AbstractModuleTest {
     }
 
     /**
-     * Checks that the sequence <code>[inline(), text( text ), inline_()]</code>,
+     * Checks that the sequence <code>[inline(), text(text), inline_()]</code>,
      * invoked on the current sink, produces the same result as
-     * {@link #getInlineBlock getInlineBlock}( text ).
+     * {@link #getInlineBlock getInlineBlock}(text).
      */
     @Test
     public void testInline() {
@@ -907,9 +907,9 @@ public abstract class AbstractSinkTest extends AbstractModuleTest {
     }
 
     /**
-     * Checks that the sequence <code>[inline(bold), text( text ), inline_()]</code>,
+     * Checks that the sequence <code>[inline(bold), text(text), inline_()]</code>,
      * invoked on the current sink, produces the same result as
-     * {@link #getInlineBoldBlock getInlineBoldBlock}( text ).
+     * {@link #getInlineBoldBlock getInlineBoldBlock}(text).
      */
     @Test
     public void testInlineBold() {
@@ -927,9 +927,9 @@ public abstract class AbstractSinkTest extends AbstractModuleTest {
     }
 
     /**
-     * Checks that the sequence <code>[inline(italic), text( text ), inline_()]</code>,
+     * Checks that the sequence <code>[inline(italic), text(text), inline_()]</code>,
      * invoked on the current sink, produces the same result as
-     * {@link #getInlineBoldBlock getInlineBoldBlock}( text ).
+     * {@link #getInlineBoldBlock getInlineBoldBlock}(text).
      */
     @Test
     public void testInlineItalic() {
@@ -947,9 +947,9 @@ public abstract class AbstractSinkTest extends AbstractModuleTest {
     }
 
     /**
-     * Checks that the sequence <code>[inline(code), text( text ), inline_()]</code>,
+     * Checks that the sequence <code>[inline(code), text(text), inline_()]</code>,
      * invoked on the current sink, produces the same result as
-     * {@link #getInlineBoldBlock getInlineBoldBlock}( text ).
+     * {@link #getInlineBoldBlock getInlineBoldBlock}(text).
      */
     @Test
     public void testInlineCode() {
@@ -1018,9 +1018,9 @@ public abstract class AbstractSinkTest extends AbstractModuleTest {
     }
 
     /**
-     * Checks that the sequence <code>[text( text )]</code>,
+     * Checks that the sequence <code>[text(text)]</code>,
      * invoked on the current sink, produces the same result as
-     * {@link #getTextBlock getTextBlock()}.
+     * {@link #getTextBlock getTextBlock()}(text).
      */
     @Test
     public void testText() {
@@ -1036,9 +1036,9 @@ public abstract class AbstractSinkTest extends AbstractModuleTest {
     }
 
     /**
-     * Checks that the sequence <code>[rawText( text )]</code>,
+     * Checks that the sequence <code>[rawText(text)]</code>,
      * invoked on the current sink, produces the same result as
-     * {@link #getRawTextBlock getRawTextBlock}( text ).
+     * {@link #getRawTextBlock getRawTextBlock}(text).
      */
     @Test
     public void testRawText() {
@@ -1056,7 +1056,7 @@ public abstract class AbstractSinkTest extends AbstractModuleTest {
     /**
      * Checks that the sequence <code>[comment(comment)]</code>,
      * invoked on the current sink, produces the same result as
-     * {@link #getCommentBlock getCommentBlock}( comment ).
+     * {@link #getCommentBlock getCommentBlock}(comment).
      * @since 1.1.1
      */
     @Test
@@ -1357,9 +1357,9 @@ public abstract class AbstractSinkTest extends AbstractModuleTest {
      * Returns a Verbatim block generated by this sink.
      * @param text The text to use.
      * @return The result of invoking a Verbatim block on the current sink.
-     * @see #testVerbatim()
+     * @see #testVerbatimSource()
      */
-    protected abstract String getVerbatimBlock(String text);
+    protected abstract String getVerbatimSourceBlock(String text);
 
     /**
      * Returns a HorizontalRule block generated by this sink.
@@ -792,21 +792,21 @@ public abstract class AbstractSinkTest extends AbstractModuleTest {
 
     /**
-     * Checks that the sequence <code>[verbatim( SinkEventAttributeSet.BOXED ), text( text ),
+     * Checks that the sequence <code>[verbatim(SinkEventAttributeSet.SOURCE), text(text),
      * verbatim_()]</code>, invoked on the current sink, produces the
@@ -792,21 +792,21 @@ public abstract class AbstractSinkTest extends AbstractModuleTest {
      * verbatim_()]</code>, invoked on the current sink, produces the
-     * same result as {@link #getVerbatimBlock getVerbatimBlock}( text ).
+     * same result as {@link #getVerbatimSourceBlock getVerbatimSourceBlock}(text).
      */
     @Test
diff --git a/doxia-modules/doxia-module-apt/src/main/java/org/apache/maven/doxia/module/apt/AptMarkup.java b/doxia-modules/doxia-module-apt/src/main/java/org/apache/maven/doxia/module/apt/AptMarkup.java
index 020bf27f..522ee2a4 100644
--- a/doxia-modules/doxia-module-apt/src/main/java/org/apache/maven/doxia/module/apt/AptMarkup.java
+++ b/doxia-modules/doxia-module-apt/src/main/java/org/apache/maven/doxia/module/apt/AptMarkup.java
@@ -99,8 +99,8 @@ public interface AptMarkup extends TextMarkup {
     /** Syntax for the bold style start: "&lt;&lt;" */
     String BOLD_START_MARKUP = StringUtils.repeat(String.valueOf(LESS_THAN), 2);
 
-    /** Syntax for the boxed verbatim start: "+------+" */
-    String BOXED_VERBATIM_START_MARKUP = PLUS + StringUtils.repeat(String.valueOf(MINUS), 6) + PLUS;
+    /** Syntax for the verbatim source start: "+------+" */
+    String VERBATIM_SOURCE_START_MARKUP = PLUS + StringUtils.repeat(String.valueOf(MINUS), 6) + PLUS;
 
     /** Syntax for the header start: " -----" */
     String HEADER_START_MARKUP = SPACE + StringUtils.repeat(String.valueOf(MINUS), 5);
@@ -135,8 +135,8 @@ public interface AptMarkup extends TextMarkup {
     /** Syntax for the mono-spaced style start: "&lt;&lt;&lt;" */
     String MONOSPACED_START_MARKUP = StringUtils.repeat(String.valueOf(LESS_THAN), 3);
 
-    /** Syntax for the non boxed verbatim start: "------" */
-    String NON_BOXED_VERBATIM_START_MARKUP = StringUtils.repeat(String.valueOf(MINUS), 6);
+    /** Syntax for the verbatim start: "------" */
+    String VERBATIM_START_MARKUP = StringUtils.repeat(String.valueOf(MINUS), 6);
 
     /** Syntax for the non breaking space: "\ " */
     String NON_BREAKING_SPACE_MARKUP = String.valueOf(BACKSLASH) + SPACE;
@@ -165,9 +165,9 @@ public interface AptMarkup extends TextMarkup {
     /** Syntax for the table row start: "*--" */
     String TABLE_ROW_START_MARKUP = STAR + StringUtils.repeat(String.valueOf(MINUS), 2);
 
-    /** Syntax for the boxed verbatim end: "+------+" */
-    String BOXED_VERBATIM_END_MARKUP = BOXED_VERBATIM_START_MARKUP;
+    /** Syntax for the verbatim source end: "+------+" */
+    String VERBATIM_SOURCE_END_MARKUP = VERBATIM_SOURCE_START_MARKUP;
 
-    /** Syntax for the non boxed verbatim end: "------" */
-    String NON_BOXED_VERBATIM_END_MARKUP = NON_BOXED_VERBATIM_START_MARKUP;
+    /** Syntax for the verbatim end: "------" */
+    String VERBATIM_END_MARKUP = VERBATIM_START_MARKUP;
 }
diff --git a/doxia-modules/doxia-module-xdoc/src/main/java/org/apache/maven/doxia/module/xdoc/XdocSink.java b/doxia-modules/doxia-module-xdoc/src/main/java/org/apache/maven/doxia/module/xdoc/XdocSink.java
index 9b991424..8828c6be 100644
--- a/doxia-modules/doxia-module-xdoc/src/main/java/org/apache/maven/doxia/module/xdoc/XdocSink.java
+++ b/doxia-modules/doxia-module-xdoc/src/main/java/org/apache/maven/doxia/module/xdoc/XdocSink.java
@@ -63,8 +63,8 @@ public class XdocSink extends Xhtml5BaseSink implements XdocMarkup {
     // Instance fields
     // ----------------------------------------------------------------------
 
-    /** An indication on if we're inside a box (verbatim). */
-    private boolean boxedFlag;
+    /** An indication on if we're inside verbatim source. */
+    private boolean sourceFlag;
 
     private String encoding;
 
@@ -124,7 +124,7 @@ public class XdocSink extends Xhtml5BaseSink implements XdocMarkup {
     protected void init() {
         super.init();
 
-        boxedFlag = false;
+        sourceFlag = false;
     }
 
     /**
@@ -378,15 +378,15 @@ public class XdocSink extends Xhtml5BaseSink implements XdocMarkup {
             atts = new SinkEventAttributeSet();
         }
 
-        boolean boxed = false;
+        boolean source = false;
 
         if (atts.isDefined(SinkEventAttributes.DECORATION)) {
-            boxedFlag = boxed = "boxed".equals(atts.getAttribute(SinkEventAttributes.DECORATION));
+            sourceFlag = source = "source".equals(atts.getAttribute(SinkEventAttributes.DECORATION));
         }
 
         atts.removeAttribute(SinkEventAttributes.DECORATION);
 
-        if (boxed) {
+        if (source) {
             writeStartTag(SOURCE_TAG, atts);
         } else {
             writeStartTag(PRE, atts);
@@ -400,7 +400,7 @@ public class XdocSink extends Xhtml5BaseSink implements XdocMarkup {
      * @see javax.swing.text.html.HTML.Tag#PRE
      */
     public void verbatim_() {
-        if (boxedFlag) {
+        if (sourceFlag) {
             writeEndTag(SOURCE_TAG);
         } else {
             writeEndTag(PRE);
@@ -408,7 +408,7 @@ public class XdocSink extends Xhtml5BaseSink implements XdocMarkup {
 
         setVerbatimFlag(false);
 
-        boxedFlag = false;
+        sourceFlag = false;
     }
 
     /**